service

package
v0.0.0-...-d7d42ed Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2024 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	Stats_GetHTML_FullMethodName = "/Stats/GetHTML"
)

Variables

var File_stats_proto protoreflect.FileDescriptor
var Stats_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "Stats",
	HandlerType: (*StatsServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetHTML",
			Handler:    _Stats_GetHTML_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "stats.proto",
}

Stats_ServiceDesc is the grpc.ServiceDesc for Stats service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterStatsServer

func RegisterStatsServer(s grpc.ServiceRegistrar, srv StatsServer)

Types

type Issue

type Issue struct {
	Id       string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Key      string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	TestType string `protobuf:"bytes,3,opt,name=testType,proto3" json:"testType,omitempty"`
	// contains filtered or unexported fields
}

func (*Issue) Descriptor deprecated

func (*Issue) Descriptor() ([]byte, []int)

Deprecated: Use Issue.ProtoReflect.Descriptor instead.

func (*Issue) GetId

func (x *Issue) GetId() string

func (*Issue) GetKey

func (x *Issue) GetKey() string

func (*Issue) GetTestType

func (x *Issue) GetTestType() string

func (*Issue) ProtoMessage

func (*Issue) ProtoMessage()

func (*Issue) ProtoReflect

func (x *Issue) ProtoReflect() protoreflect.Message

func (*Issue) Reset

func (x *Issue) Reset()

func (*Issue) String

func (x *Issue) String() string

type StatsClient

type StatsClient interface {
	GetHTML(ctx context.Context, in *StatsReq, opts ...grpc.CallOption) (*StatsRes, error)
}

StatsClient is the client API for Stats service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewStatsClient

func NewStatsClient(cc grpc.ClientConnInterface) StatsClient

type StatsReq

type StatsReq struct {
	Issues []*Issue `protobuf:"bytes,1,rep,name=issues,proto3" json:"issues,omitempty"`
	// contains filtered or unexported fields
}

func (*StatsReq) Descriptor deprecated

func (*StatsReq) Descriptor() ([]byte, []int)

Deprecated: Use StatsReq.ProtoReflect.Descriptor instead.

func (*StatsReq) GetIssues

func (x *StatsReq) GetIssues() []*Issue

func (*StatsReq) ProtoMessage

func (*StatsReq) ProtoMessage()

func (*StatsReq) ProtoReflect

func (x *StatsReq) ProtoReflect() protoreflect.Message

func (*StatsReq) Reset

func (x *StatsReq) Reset()

func (*StatsReq) String

func (x *StatsReq) String() string

type StatsRes

type StatsRes struct {
	Html string `protobuf:"bytes,1,opt,name=html,proto3" json:"html,omitempty"`
	// contains filtered or unexported fields
}

func (*StatsRes) Descriptor deprecated

func (*StatsRes) Descriptor() ([]byte, []int)

Deprecated: Use StatsRes.ProtoReflect.Descriptor instead.

func (*StatsRes) GetHtml

func (x *StatsRes) GetHtml() string

func (*StatsRes) ProtoMessage

func (*StatsRes) ProtoMessage()

func (*StatsRes) ProtoReflect

func (x *StatsRes) ProtoReflect() protoreflect.Message

func (*StatsRes) Reset

func (x *StatsRes) Reset()

func (*StatsRes) String

func (x *StatsRes) String() string

type StatsServer

type StatsServer interface {
	GetHTML(context.Context, *StatsReq) (*StatsRes, error)
	// contains filtered or unexported methods
}

StatsServer is the server API for Stats service. All implementations must embed UnimplementedStatsServer for forward compatibility

type UnimplementedStatsServer

type UnimplementedStatsServer struct {
}

UnimplementedStatsServer must be embedded to have forward compatible implementations.

func (UnimplementedStatsServer) GetHTML

type UnsafeStatsServer

type UnsafeStatsServer interface {
	// contains filtered or unexported methods
}

UnsafeStatsServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StatsServer will result in compilation errors.

Jump to