Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterConfluenceServer(s grpc.ServiceRegistrar, srv ConfluenceServer)
- type ConfluenceClient
- type ConfluenceServer
- type PageCreateReq
- func (*PageCreateReq) Descriptor() ([]byte, []int)deprecated
- func (x *PageCreateReq) GetConfleunceUsername() string
- func (x *PageCreateReq) GetConfluenceInstance() string
- func (x *PageCreateReq) GetConfluenceToken() string
- func (x *PageCreateReq) GetHtmlContent() string
- func (x *PageCreateReq) GetParentPageId() string
- func (x *PageCreateReq) GetSpaceId() string
- func (x *PageCreateReq) GetTitle() string
- func (*PageCreateReq) ProtoMessage()
- func (x *PageCreateReq) ProtoReflect() protoreflect.Message
- func (x *PageCreateReq) Reset()
- func (x *PageCreateReq) String() string
- type PageReq
- func (*PageReq) Descriptor() ([]byte, []int)deprecated
- func (x *PageReq) GetConfleunceUsername() string
- func (x *PageReq) GetConfluenceInstance() string
- func (x *PageReq) GetConfluenceToken() string
- func (x *PageReq) GetId() int64
- func (*PageReq) ProtoMessage()
- func (x *PageReq) ProtoReflect() protoreflect.Message
- func (x *PageReq) Reset()
- func (x *PageReq) String() string
- type PageRes
- func (*PageRes) Descriptor() ([]byte, []int)deprecated
- func (x *PageRes) GetHtml() string
- func (x *PageRes) GetId() string
- func (x *PageRes) GetTitle() string
- func (*PageRes) ProtoMessage()
- func (x *PageRes) ProtoReflect() protoreflect.Message
- func (x *PageRes) Reset()
- func (x *PageRes) String() string
- type UnimplementedConfluenceServer
- type UnsafeConfluenceServer
Constants ¶
const ( Confluence_GetPage_FullMethodName = "/Confluence/GetPage" Confluence_CreatePage_FullMethodName = "/Confluence/CreatePage" )
Variables ¶
var Confluence_ServiceDesc = grpc.ServiceDesc{ ServiceName: "Confluence", HandlerType: (*ConfluenceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetPage", Handler: _Confluence_GetPage_Handler, }, { MethodName: "CreatePage", Handler: _Confluence_CreatePage_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "confluence.proto", }
Confluence_ServiceDesc is the grpc.ServiceDesc for Confluence service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_confluence_proto protoreflect.FileDescriptor
Functions ¶
func RegisterConfluenceServer ¶
func RegisterConfluenceServer(s grpc.ServiceRegistrar, srv ConfluenceServer)
Types ¶
type ConfluenceClient ¶
type ConfluenceClient interface {
GetPage(ctx context.Context, in *PageReq, opts ...grpc.CallOption) (*PageRes, error)
CreatePage(ctx context.Context, in *PageCreateReq, opts ...grpc.CallOption) (*PageRes, error)
}
ConfluenceClient is the client API for Confluence service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewConfluenceClient ¶
func NewConfluenceClient(cc grpc.ClientConnInterface) ConfluenceClient
type ConfluenceServer ¶
type ConfluenceServer interface {
GetPage(context.Context, *PageReq) (*PageRes, error)
CreatePage(context.Context, *PageCreateReq) (*PageRes, error)
// contains filtered or unexported methods
}
ConfluenceServer is the server API for Confluence service. All implementations must embed UnimplementedConfluenceServer for forward compatibility
type PageCreateReq ¶
type PageCreateReq struct {
HtmlContent string `protobuf:"bytes,1,opt,name=htmlContent,proto3" json:"htmlContent,omitempty"`
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
SpaceId string `protobuf:"bytes,3,opt,name=spaceId,proto3" json:"spaceId,omitempty"`
ParentPageId string `protobuf:"bytes,4,opt,name=parentPageId,proto3" json:"parentPageId,omitempty"`
ConfluenceInstance string `protobuf:"bytes,5,opt,name=confluenceInstance,proto3" json:"confluenceInstance,omitempty"`
ConfleunceUsername string `protobuf:"bytes,6,opt,name=confleunceUsername,proto3" json:"confleunceUsername,omitempty"`
ConfluenceToken string `protobuf:"bytes,7,opt,name=confluenceToken,proto3" json:"confluenceToken,omitempty"`
// contains filtered or unexported fields
}
func (*PageCreateReq) Descriptor
deprecated
func (*PageCreateReq) Descriptor() ([]byte, []int)
Deprecated: Use PageCreateReq.ProtoReflect.Descriptor instead.
func (*PageCreateReq) GetConfleunceUsername ¶
func (x *PageCreateReq) GetConfleunceUsername() string
func (*PageCreateReq) GetConfluenceInstance ¶
func (x *PageCreateReq) GetConfluenceInstance() string
func (*PageCreateReq) GetConfluenceToken ¶
func (x *PageCreateReq) GetConfluenceToken() string
func (*PageCreateReq) GetHtmlContent ¶
func (x *PageCreateReq) GetHtmlContent() string
func (*PageCreateReq) GetParentPageId ¶
func (x *PageCreateReq) GetParentPageId() string
func (*PageCreateReq) GetSpaceId ¶
func (x *PageCreateReq) GetSpaceId() string
func (*PageCreateReq) GetTitle ¶
func (x *PageCreateReq) GetTitle() string
func (*PageCreateReq) ProtoMessage ¶
func (*PageCreateReq) ProtoMessage()
func (*PageCreateReq) ProtoReflect ¶
func (x *PageCreateReq) ProtoReflect() protoreflect.Message
func (*PageCreateReq) Reset ¶
func (x *PageCreateReq) Reset()
func (*PageCreateReq) String ¶
func (x *PageCreateReq) String() string
type PageReq ¶
type PageReq struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
ConfluenceInstance string `protobuf:"bytes,2,opt,name=confluenceInstance,proto3" json:"confluenceInstance,omitempty"`
ConfleunceUsername string `protobuf:"bytes,3,opt,name=confleunceUsername,proto3" json:"confleunceUsername,omitempty"`
ConfluenceToken string `protobuf:"bytes,4,opt,name=confluenceToken,proto3" json:"confluenceToken,omitempty"`
// contains filtered or unexported fields
}
func (*PageReq) Descriptor
deprecated
func (*PageReq) GetConfleunceUsername ¶
func (*PageReq) GetConfluenceInstance ¶
func (*PageReq) GetConfluenceToken ¶
func (*PageReq) ProtoMessage ¶
func (*PageReq) ProtoMessage()
func (*PageReq) ProtoReflect ¶
func (x *PageReq) ProtoReflect() protoreflect.Message
type PageRes ¶
type PageRes struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
Html string `protobuf:"bytes,3,opt,name=html,proto3" json:"html,omitempty"`
// contains filtered or unexported fields
}
func (*PageRes) Descriptor
deprecated
func (*PageRes) ProtoMessage ¶
func (*PageRes) ProtoMessage()
func (*PageRes) ProtoReflect ¶
func (x *PageRes) ProtoReflect() protoreflect.Message
type UnimplementedConfluenceServer ¶
type UnimplementedConfluenceServer struct {
}
UnimplementedConfluenceServer must be embedded to have forward compatible implementations.
func (UnimplementedConfluenceServer) CreatePage ¶
func (UnimplementedConfluenceServer) CreatePage(context.Context, *PageCreateReq) (*PageRes, error)
type UnsafeConfluenceServer ¶
type UnsafeConfluenceServer interface {
// contains filtered or unexported methods
}
UnsafeConfluenceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConfluenceServer will result in compilation errors.