Documentation
¶
Index ¶
Constants ¶
const (
Stats_GetHTML_FullMethodName = "/Stats/GetHTML"
)
Variables ¶
var File_stats_proto protoreflect.FileDescriptor
var Stats_ServiceDesc = grpc.ServiceDesc{ ServiceName: "Stats", HandlerType: (*StatsServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetHTML", Handler: _Stats_GetHTML_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "stats.proto", }
Stats_ServiceDesc is the grpc.ServiceDesc for Stats service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterStatsServer ¶
func RegisterStatsServer(s grpc.ServiceRegistrar, srv StatsServer)
Types ¶
type Issue ¶
type Issue struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Key string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
TestType string `protobuf:"bytes,3,opt,name=testType,proto3" json:"testType,omitempty"`
// contains filtered or unexported fields
}
func (*Issue) Descriptor
deprecated
func (*Issue) GetTestType ¶
func (*Issue) ProtoMessage ¶
func (*Issue) ProtoMessage()
func (*Issue) ProtoReflect ¶
func (x *Issue) ProtoReflect() protoreflect.Message
type StatsClient ¶
type StatsClient interface {
GetHTML(ctx context.Context, in *StatsReq, opts ...grpc.CallOption) (*StatsRes, error)
}
StatsClient is the client API for Stats service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewStatsClient ¶
func NewStatsClient(cc grpc.ClientConnInterface) StatsClient
type StatsReq ¶
type StatsReq struct {
Issues []*Issue `protobuf:"bytes,1,rep,name=issues,proto3" json:"issues,omitempty"`
// contains filtered or unexported fields
}
func (*StatsReq) Descriptor
deprecated
func (*StatsReq) ProtoMessage ¶
func (*StatsReq) ProtoMessage()
func (*StatsReq) ProtoReflect ¶
func (x *StatsReq) ProtoReflect() protoreflect.Message
type StatsRes ¶
type StatsRes struct {
Html string `protobuf:"bytes,1,opt,name=html,proto3" json:"html,omitempty"`
// contains filtered or unexported fields
}
func (*StatsRes) Descriptor
deprecated
func (*StatsRes) ProtoMessage ¶
func (*StatsRes) ProtoMessage()
func (*StatsRes) ProtoReflect ¶
func (x *StatsRes) ProtoReflect() protoreflect.Message
type StatsServer ¶
type StatsServer interface {
GetHTML(context.Context, *StatsReq) (*StatsRes, error)
// contains filtered or unexported methods
}
StatsServer is the server API for Stats service. All implementations must embed UnimplementedStatsServer for forward compatibility
type UnimplementedStatsServer ¶
type UnimplementedStatsServer struct {
}
UnimplementedStatsServer must be embedded to have forward compatible implementations.
type UnsafeStatsServer ¶
type UnsafeStatsServer interface {
// contains filtered or unexported methods
}
UnsafeStatsServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StatsServer will result in compilation errors.